@@ -194,6 +194,8 @@ public class TestTree {
         column.packStart(renderer, true);
         column.addAttributeMapping(renderer,
                 CellRendererToggle.Attribute.ACTIVE, dataBool);
+        column.addListener(new SortedColumnListener(dataBool, sortable));
+        sortable.setSortMethod(new JudgementColumn(), dataBool);
 
         // Create the Timestamp column.
         column = new TreeViewColumn();
@@ -243,16 +245,11 @@ public class TestTree {
     protected class TreeFilter implements TreeModelFilterVisibleMethod {
         public boolean filter(TreeModel model, TreeIter iter) {
             // This is a simple filter.
-            //
             // Check if the filter toggle has been selected.
             if (ckfilter.getState()) {
                 // If it has then filter this row based on the boolean
                 // field of the model.
-                if (model.getValue(iter, dataBool)) {
-                    return true;
-                } else {
-                    return false;
-                }
+                return model.getValue(iter, dataBool);
             } else {
                 // If the toggle has not been selected, no filtering is
                 // performed.
@@ -308,6 +305,20 @@ public class TestTree {
         }
     }
 
+    protected class JudgementColumn implements TreeIterComparison {
+        public int compareTreeIters(TreeModel store, TreeIter a, TreeIter b) {
+            boolean as = store.getValue(a, dataBool);
+            boolean bs = store.getValue(b, dataBool);
+            if (!as && bs) {
+                return -1;
+            } else if (as && !bs) {
+                return 1;
+            } else {
+                return 0;
+            }
+        }
+    }
+
     protected class TimestampColumn implements TreeIterComparison {
         public int compareTreeIters(TreeModel store, TreeIter a, TreeIter b) {
             String as = store.getValue(a, dataString2);
