@@ -21,11 +21,25 @@ import org.gnu.glib.Handle;
 
 /**
  * A Calendar is a widget that displays a calendar one month at a time.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may in the future have an equivalent in
+ *             java-gnome 4.0, try looking for
+ *             <code>org.gnome.gtk.Calendar</code>.
+ *             You should be aware that there is a considerably different API
+ *             in the new library: the architecture is completely different
+ *             and most notably internals are no longer exposed to public view.
  */
 public class Calendar extends Widget {
 
     /**
      * Create a new Calendar object with the current date selected.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Calendar() {
         super(gtk_calendar_new());
@@ -33,6 +47,10 @@ public class Calendar extends Widget {
 
     /**
      * Construct a calendar using a handle to a native resource.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Calendar(Handle handle) {
         super(handle);
@@ -40,6 +58,10 @@ public class Calendar extends Widget {
 
     /**
      * Internal static factory method to be used by Java-Gnome only.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public static Calendar getCalendar(Handle handle) {
         if (handle == null) {
@@ -62,6 +84,10 @@ public class Calendar extends Widget {
      *            The month to select. This value is zero based.
      * @param year
      *            The year the month is in.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void selectMonth(int month, int year) {
         Calendar.gtk_calendar_select_month(getHandle(), month, year);
@@ -73,6 +99,10 @@ public class Calendar extends Widget {
      * @param day
      *            A day number between 1 and 31, or 0 to unselect the currently
      *            selected day.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void selectDay(int day) {
         Calendar.gtk_calendar_select_day(getHandle(), day);
@@ -83,6 +113,10 @@ public class Calendar extends Widget {
      * 
      * @param day
      *            The day number to mark between 1 and 31.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void markDay(int day) {
         Calendar.gtk_calendar_mark_day(getHandle(), day);
@@ -93,6 +127,10 @@ public class Calendar extends Widget {
      * 
      * @param day
      *            The day number to unmark between 1 and 31.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void unmarkDay(int day) {
         Calendar.gtk_calendar_unmark_day(getHandle(), day);
@@ -100,6 +138,10 @@ public class Calendar extends Widget {
 
     /**
      * Remove all visual marks.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void clearMarks() {
         Calendar.gtk_calendar_clear_marks(getHandle());
@@ -111,6 +153,10 @@ public class Calendar extends Widget {
      * 
      * @param displayOptions
      *            The options to set.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setDisplayOptions(CalendarDisplayOptions displayOptions) {
         gtk_calendar_set_display_options(getHandle(), displayOptions.getValue());
@@ -119,46 +165,40 @@ public class Calendar extends Widget {
     /**
      * Gets the display options (whether to display the heading and the month
      * headings.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public CalendarDisplayOptions getDisplayOptions() {
         return CalendarDisplayOptions
                 .intern(gtk_calendar_get_display_options(getHandle()));
     }
 
-    /**
-     * Gets the selected date from the Calendar widget.
-     * 
-     * @return A Calendar object that represents the date selected in the
-     *         widget.
-     * @deprecated the form returning java.util.Calendar is deprecated and will
-     *             be replaced. Use {@link #getYearMonthDay()} as a workaround
-     *             until libgtk-java 2.10, when getDate() will return an int[3]
-     *             instead.
-     */
-    public java.util.Calendar getDate() {
-        int[] year = new int[1];
-        int[] month = new int[1];
-        int[] day = new int[1];
-        Calendar.gtk_calendar_get_date(getHandle(), year, month, day);
-        java.util.Calendar cal = java.util.Calendar.getInstance();
-        cal.set(java.util.Calendar.YEAR, year[0]);
-        cal.set(java.util.Calendar.MONTH, month[0]);
-        cal.set(java.util.Calendar.DAY_OF_MONTH, day[0]);
-        return cal;
-    }
-
     /**
      * Gets the selected date from a Calendar.
+     * <p>
+     * <i>Historical note: getDate() used to return java.util.Calendar. This
+     * caused some class library implementations to fault in their entire
+     * TimeZone subsystems which led to a very deep bug on some architectures.
+     * This method was therefore changed as of libgtk-java 2.10 to the int[3]
+     * implementation here.</i>
+     * </p>
      * 
      * @return a three wide array of integers: the array at [0] is the year (4
      *         digits), the array at [1] is the month (range from 1-12), and the
      *         array at [2] is the numeric day (range from 1-{28,29,30,31}).
+     * @since 2.10
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
-    public int[] getYearMonthDay() {
+    public int[] getDate() {
         int[] in = new int[3];
         int[] out = new int[3];
 
-        Calendar.getYearMonthDay(getHandle(), in);
+        Calendar.gtk_calendar_get_date(getHandle(), in);
 
         // necessary to use intermediate variables otherwise you can get memory
         // problems.
@@ -178,6 +218,10 @@ public class Calendar extends Widget {
      * <code>thaw()</code> method.
      * 
      * @deprecated
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void freeze() {
         Calendar.gtk_calendar_freeze(getHandle());
@@ -188,6 +232,10 @@ public class Calendar extends Widget {
      * <code>freeze()</code> are displayed.
      * 
      * @deprecated
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void thaw() {
         Calendar.gtk_calendar_thaw(getHandle());
@@ -199,6 +247,10 @@ public class Calendar extends Widget {
 
     /**
      * Listeners for handling calendar events
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     private Vector calendarListeners = null;
 
@@ -206,6 +258,10 @@ public class Calendar extends Widget {
      * Register an object to handle calendar events.
      * 
      * @see org.gnu.gtk.event.CalendarListener
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void addListener(CalendarListener listener) {
         // Don't add the listener a second time if it is in the Vector.
@@ -229,6 +285,10 @@ public class Calendar extends Widget {
      * Removes a listener
      * 
      * @see #addListener(CalendarListener)
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void removeListener(CalendarListener listener) {
         int i = findListener(calendarListeners, listener);
@@ -313,6 +373,10 @@ public class Calendar extends Widget {
     /**
      * Implementation method to build an EventMap for this widget class. Not
      * useful (or supported) for application use.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     private static void addEvents(EventMap anEvtMap) {
         anEvtMap.addEvent("day_selected", "handleDaySelected",
@@ -332,6 +396,10 @@ public class Calendar extends Widget {
 
     /**
      * Retrieve the runtime type used by the GLib library.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public static Type getType() {
         return new Type(gtk_calendar_get_type());
@@ -361,10 +429,7 @@ public class Calendar extends Widget {
     native static final protected int gtk_calendar_get_display_options(
             Handle calendar);
 
-    native static final protected void gtk_calendar_get_date(Handle calendar,
-            int[] year, int[] month, int[] day);
-
-    native static final private void getYearMonthDay(Handle calendar,
+    native static final private void gtk_calendar_get_date(Handle calendar,
             int[] triple);
 
     native static final protected void gtk_calendar_freeze(Handle calendar);
@@ -374,5 +439,9 @@ public class Calendar extends Widget {
     /*
      * Deprecated functions. native static final private void
      * gtk_calendar_display_options(Handle calendar, int flags);
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
 }
