@@ -14,9 +14,9 @@ import java.util.HashMap;
 import java.util.List;
 
 import org.gnu.gdk.Pixbuf;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.glib.Value;
-import org.gnu.glib.Handle;
 
 /**
  * The ListStore is the gtk Model used for constructing Lists and tables to be
@@ -36,6 +36,16 @@ import org.gnu.glib.Handle;
  * object.
  * 
  * @author Mark Howard &lt;mh@debian.org&gt;
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may in the future have an equivalent in
+ *             java-gnome 4.0, try looking for
+ *             <code>org.gnome.gtk.ListStore</code>.
+ *             You should be aware that there is a considerably different API
+ *             in the new library: the architecture is completely different
+ *             and most notably internals are no longer exposed to public view.
  */
 public class ListStore extends TreeModel implements TreeSortable,
         TreeDragSource, TreeDragDest {
@@ -54,6 +64,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            a list of dataColumns for the store. These should be created
      *            as private variables of the required type - they will be
      *            needed later.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public ListStore(DataColumn[] dataColumns) {
         super(initListStore(dataColumns));
@@ -82,6 +96,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @param aRow
      *            a row to be added to the list
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void addRow(DataRow aRow) {
 
@@ -110,6 +128,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @param aRow
      *            a row to be added to the list
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void addRowAt(DataRow aRow, int aPosition) {
 
@@ -131,6 +153,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param rowIter
      * @param dataCol
      * @param rowItem
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     private void trySetValue(TreeIter rowIter, DataColumn dataCol,
             Object rowItem) {
@@ -179,6 +205,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @see TreeModel#getIter(TreePath)
      * @see TreeModel#getFirstIter()
      * @see TreeSelection
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public DataRow getRowAt(TreeIter aIter) {
 
@@ -234,6 +264,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param aIter
      *            a <code>TreeIter</code> pointing to a row in the tree.
      * @see #getRowAt(TreeIter)
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setRowAt(DataRow aRow, TreeIter aIter) {
 
@@ -254,6 +288,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @param dataColumns
      *            the data columns to be set
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setColumnTypes(DataColumn[] dataColumns) {
         int[] intTypes = new int[dataColumns.length];
@@ -276,6 +314,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param aCol
      *            the column index
      * @return the corresponding DataColumn
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public DataColumn getDataColumn(int aCol) {
         return (DataColumn) columnTypes.get(aCol);
@@ -286,6 +328,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * <code>DataColumn</code> object.
      * 
      * @return the list of <code>DataColumn</code>'s
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public List getAllDataColumns() {
         return columnTypes;
@@ -306,6 +352,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            The value to store. This <em>must</em> be of the same type
      *            for the column as that set in the constructor to the
      *            ListStore.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnString dataBlock, String value) {
         Value val = new Value(Type.STRING());
@@ -334,6 +384,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            {@link #appendRow()}.
      * @param value
      *            The value to be set.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnStockItem dataBlock,
             GtkStockItem value) {
@@ -363,6 +417,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            {@link #appendRow()}.
      * @param value
      *            The value to be set.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnIconSize dataBlock,
             IconSize value) {
@@ -387,6 +445,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            The value to store. This <em>must</em> be of the same type
      *            for the column as that set in the constructor to the
      *            ListStore.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnInt dataBlock, int value) {
         Value val = new Value(Type.INT());
@@ -416,6 +478,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param value
      *            The <code>long</code> value to set into this row.
      * @since 2.8.5
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnLong dataBlock, long value) {
         Value val = new Value(Type.LONG());
@@ -439,6 +505,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            The value to store. This <em>must</em> be of the same type
      *            for the column as that set in the constructor to the
      *            ListStore.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnBoolean dataBlock,
             boolean value) {
@@ -461,6 +531,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            The data block to store the value in.
      * @param value
      *            The value to store.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnDouble dataBlock, double value) {
         Value val = new Value(Type.DOUBLE());
@@ -481,6 +555,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            {@link #appendRow()}.
      * @param value
      *            The value to be set.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnObject dataBlock, Object value) {
         Value val = new Value(Type.JAVA_OBJECT());
@@ -505,11 +583,15 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param value
      *            The value to be set. This <em>must</em> match the type for
      *            that dataBlock, as set in the constructor.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setValue(TreeIter iter, DataColumnPixbuf dataBlock,
-            org.gnu.gdk.Pixbuf value) {
-        Value val = new Value(Type.PIXBUF());
-        val.setPixbuf(value);
+            Pixbuf value) {
+        Value val = new Value(Type.OBJECT());
+        val.setJavaObject(value);
         gtk_list_store_set_value(getHandle(), iter.getHandle(), dataBlock
                 .getColumn(), val.getHandle());
     }
@@ -522,6 +604,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param iter
      *            iterator for the row to be removed.
      * @return TRUE if iter is valid, FALSE if not.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public boolean removeRow(TreeIter iter) {
 
@@ -538,6 +624,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * @param position
      *            The position to place the new row, starting at 0.
      * @return Iterator for the new row
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public TreeIter insertRow(int position) {
         return TreeIter.getTreeIter(
@@ -551,6 +641,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @param sibling
      * @return Iterator for the new row
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public TreeIter insertRowBefore(TreeIter sibling) {
         Handle siblingHandle = (sibling == null ? null : sibling.getHandle());
@@ -565,6 +659,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @param sibling
      * @return Iterator for the new row.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public TreeIter insertRowAfter(TreeIter sibling) {
         Handle siblingHandle = (sibling == null ? null : sibling.getHandle());
@@ -578,6 +676,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * called.
      * 
      * @return Iterator for the new row
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public TreeIter prependRow() {
         return TreeIter.getTreeIter(gtk_list_store_prepend(getHandle()), this);
@@ -587,6 +689,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * Appends a new row to the store
      * 
      * @return Iterator for the new row
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public TreeIter appendRow() {
         return TreeIter.getTreeIter(gtk_list_store_append(getHandle()), this);
@@ -594,6 +700,10 @@ public class ListStore extends TreeModel implements TreeSortable,
 
     /**
      * Removes all rows from the list store.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void clear() {
         gtk_list_store_clear(getHandle());
@@ -601,6 +711,10 @@ public class ListStore extends TreeModel implements TreeSortable,
 
     /**
      * Retrieve the runtime type used by the GLib library.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public static Type getType() {
         return new Type(gtk_list_store_get_type());
@@ -612,6 +726,10 @@ public class ListStore extends TreeModel implements TreeSortable,
 
     /**
      * Set the column in the list to sort on.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setSortColumn(DataColumn column, SortType order) {
         TreeSortableHelper.setSortColumn(this, column, order);
@@ -625,6 +743,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @return A DataColumn object representing the currently sorted column or
      *         <tt>null</tt> if there is no column currently sorted.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public DataColumn getSortColumn() {
         return TreeSortableHelper.getSortColumn(this);
@@ -635,6 +757,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * 
      * @return A SortType object defining the current sorting order of the store
      *         or <tt>null</tt> if there is no current sort order.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public SortType getSortOrder() {
         return TreeSortableHelper.getSortOrder(this);
@@ -643,6 +769,10 @@ public class ListStore extends TreeModel implements TreeSortable,
     /**
      * Set the class used to sort the list according to the values stored in the
      * given DataColumn.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void setSortMethod(TreeIterComparison method, DataColumn column) {
         TreeSortableHelper.setSortMethod(this, method, column);
@@ -651,6 +781,10 @@ public class ListStore extends TreeModel implements TreeSortable,
     /**
      * Call-back method invoked by the JNI code when sorting is required. This
      * is for internal use only.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public int handleCompareFunc(Handle model, Handle aIter, Handle bIter,
             int col) {
@@ -665,11 +799,25 @@ public class ListStore extends TreeModel implements TreeSortable,
         }
     }
 
+    /**
+     * This method has not yet been implemented.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
+     */
     public void setDragDestListener(TreeDragDestListener listener) {
         // TODO
         throw new RuntimeException("Not yet implemented");
     }
 
+    /**
+     * This method has not yet been implemented.
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
+     */
     public void setDragSourceListener(TreeDragSourceListener listener) {
         // TODO
         throw new RuntimeException("Not yet implemented");
@@ -680,6 +828,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * only works with unsorted stores.
      * 
      * @since 2.2
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void swapRows(TreeIter a, TreeIter b) {
         gtk_list_store_swap(getHandle(), a.getHandle(), b.getHandle());
@@ -689,6 +841,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * Moves iter to the end of the model
      * 
      * @since 2.2
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void moveRowToEnd(TreeIter iter) {
         gtk_list_store_move_before(getHandle(), iter.getHandle(), null);
@@ -700,6 +856,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * that this function only works with unsorted stores.
      * 
      * @since 2.2
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void moveRowAfter(TreeIter iter, TreeIter position) {
         gtk_list_store_move_after(getHandle(), iter.getHandle(), position
@@ -710,6 +870,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * Moves iter in this store to the start of the store.
      * 
      * @since 2.2
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void moveRowToStart(TreeIter iter) {
         gtk_list_store_move_after(getHandle(), iter.getHandle(), null);
@@ -721,6 +885,10 @@ public class ListStore extends TreeModel implements TreeSortable,
      * function only works with unsorted stores.
      * 
      * @since 2.2
+     * @deprecated Superceeded by java-gnome 4.0; a method along these lines
+     *             may well exist in the new bindings, but if it does it likely
+     *             has a different name or signature due to the shift to an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void moveRowBefore(TreeIter iter, TreeIter position) {
         gtk_list_store_move_before(getHandle(), iter.getHandle(), position
