@@ -11,13 +11,11 @@ package org.gnu.gtk;
 
 import org.gnu.glib.Struct;
 
-public class TextLine extends Struct 
-{
-    /****************************************
+public class TextLine extends Struct {
+    /***************************************************************************
      * BEGINNING OF GENERATED CODE
-     ****************************************/
-    /****************************************
+     **************************************************************************/
+    /***************************************************************************
      * END OF GENERATED CODE
-     ****************************************/
+     **************************************************************************/
 }
-
