@@ -15,11 +15,15 @@ package org.gnu.gtk.event;
 
 public class DragOriginAdapter implements DragOriginListener {
 
-	public void dragStarted(StartDragEvent event) {}
+    public void dragStarted(StartDragEvent event) {
+    }
 
-	public void dragEnded(EndDragEvent event) {}
+    public void dragEnded(EndDragEvent event) {
+    }
 
-	public void dataRequested(RequestDragDataEvent event) {}
+    public void dataRequested(RequestDragDataEvent event) {
+    }
 
-	public void dataDeleted(DeleteDragDataEvent event) {}
+    public void dataDeleted(DeleteDragDataEvent event) {
+    }
 }
