@@ -9,10 +9,19 @@
 
 package org.gnu.pango;
 
-import org.gnu.javagnome.Enum;
+import org.gnu.glib.Enum;
 
 /**
  * Describes how to wrap the lines of a PangoLayout to the desired width.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may exist in java-gnome 4.0; look out for
+ *             <code>org.gnome.pango.WrapMode</code>.
+ *             As this package was never fully implemented in java-gnome 2.x,
+ *             however, any new code written will have a considerably different
+ *             public API.
  */
 public class WrapMode extends Enum {
     static final private int _WORD = 0;
@@ -30,6 +39,10 @@ public class WrapMode extends Enum {
     /**
      * Wrap lines at word boundaries, but fall back to character boundaries if
      * there is not enough space for a full word.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     static final public WrapMode WORD_CHAR = new WrapMode(_WORD_CHAR);
 
