@@ -10,9 +10,11 @@
 #include <jni.h>
 #include <atk/atk.h>
 #include "jg_jnu.h"
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_atk_Registry
 #define _Included_org_gnu_atk_Registry
+#include "org_gnu_atk_Registry.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -57,7 +59,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_atk_Registry_atk_1registry_1get_1factory
   (JNIEnv *env, jclass cls, jobject reg, jint type)
 {
 	AtkRegistry* reg_g = (AtkRegistry*)getPointerFromHandle(env, reg);
-	return getGObjectHandle(env, atk_registry_get_factory(reg_g, (GType)type));
+	return getGObjectHandle(env, G_OBJECT(atk_registry_get_factory(reg_g, (GType)type)));
 }
 
 /*
@@ -67,7 +69,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_atk_Registry_atk_1registry_1get_1factory
 JNIEXPORT jobject JNICALL Java_org_gnu_atk_Registry_atk_1get_1default_1registry
   (JNIEnv *env, jclass cls)
 {
-	return getGObjectHandle(env, atk_get_default_registry());
+	return getGObjectHandle(env, G_OBJECT(atk_get_default_registry()));
 }
 
 #ifdef __cplusplus
