@@ -27,7 +27,7 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_atk_StateType_atk_1state_1type_1get_1n
     *env, jclass cls, jint type) 
 {
     AtkStateType type_g = (AtkStateType) type;
-    gchar *result_g = (gchar *)atk_state_type_get_name (type_g);
+    const gchar *result_g = (gchar *)atk_state_type_get_name (type_g);
     jsize result_len = result_g ? strlen (result_g) : 0;
     jbyteArray result_j = result_g ? (*env)->NewByteArray (env, result_len) : NULL;
     if (result_g) 
