@@ -9,18 +9,14 @@
 
 #include <jni.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_gdk_Image.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GdkVisual * GdkImage_get_visual (GdkImage * cptr) 
-{
-    return cptr->visual;
-}
-
 /*
  * Class:     org.gnu.gdk.Image
  * Method:    getVisual
@@ -28,10 +24,10 @@ GdkVisual * GdkImage_get_visual (GdkImage * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Image_getVisual (JNIEnv *env, jclass cls, jobject obj) 
 {
     GdkImage *obj_g = (GdkImage *)getPointerFromHandle(env, obj);
-    return getHandleFromPointer(env, GdkImage_get_visual (obj_g));
+    return getGObjectHandle(env, G_OBJECT(obj_g->visual));
 }
 
-GdkByteOrder GdkImage_get_byte_order (GdkImage * cptr) 
+static GdkByteOrder GdkImage_get_byte_order (GdkImage * cptr) 
 {
     return cptr->byte_order;
 }
@@ -46,7 +42,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getByteOrder (JNIEnv *env, jclass
     return (jint) (GdkImage_get_byte_order (obj_g));
 }
 
-guint32 GdkImage_get_width (GdkImage * cptr) 
+static guint32 GdkImage_get_width (GdkImage * cptr) 
 {
     return cptr->width;
 }
@@ -61,7 +57,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getWidth (JNIEnv *env, jclass cls,
     return (jint) (GdkImage_get_width (obj_g));
 }
 
-guint32 GdkImage_get_height (GdkImage * cptr) 
+static guint32 GdkImage_get_height (GdkImage * cptr) 
 {
     return cptr->height;
 }
@@ -76,7 +72,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getHeight (JNIEnv *env, jclass cls
     return (jint) (GdkImage_get_height (obj_g));
 }
 
-guint32 GdkImage_get_depth (GdkImage * cptr) 
+static guint32 GdkImage_get_depth (GdkImage * cptr) 
 {
     return cptr->depth;
 }
@@ -91,7 +87,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getDepth (JNIEnv *env, jclass cls,
     return (jint) (GdkImage_get_depth (obj_g));
 }
 
-guint32 GdkImage_get_bpp (GdkImage * cptr) 
+static guint32 GdkImage_get_bpp (GdkImage * cptr) 
 {
     return cptr->bpp;
 }
@@ -106,7 +102,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getBpp (JNIEnv *env, jclass cls, j
     return (jint) (GdkImage_get_bpp (obj_g));
 }
 
-guint32 GdkImage_get_bpl (GdkImage * cptr) 
+static guint32 GdkImage_get_bpl (GdkImage * cptr) 
 {
     return cptr->bpl;
 }
@@ -121,7 +117,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Image_getBpl (JNIEnv *env, jclass cls, j
     return (jint) (GdkImage_get_bpl (obj_g));
 }
 
-guint32 GdkImage_get_bits_per_pixel (GdkImage * cptr) 
+static guint32 GdkImage_get_bits_per_pixel (GdkImage * cptr) 
 {
     return cptr->bits_per_pixel;
 }
@@ -156,7 +152,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Image_gdk_1image_1new (JNIEnv *env, j
     GdkVisual *visual_g = (GdkVisual *)getPointerFromHandle(env, visual);
     gint32 width_g = (gint32) width;
     gint32 height_g = (gint32) height;
-    return getHandleFromPointer(env, gdk_image_new (type_g, visual_g, width_g, height_g));
+    return getGObjectHandle(env, G_OBJECT(gdk_image_new (type_g, visual_g, width_g, height_g)));
 }
 
 /*
@@ -206,7 +202,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Image_gdk_1image_1get_1colormap (JNIE
     cls, jobject image) 
 {
     GdkImage *image_g = (GdkImage *)getPointerFromHandle(env, image);
-    return getHandleFromPointer(env, gdk_image_get_colormap (image_g));
+    return getGObjectHandle(env, G_OBJECT(gdk_image_get_colormap (image_g)));
 }
 
 
