@@ -205,7 +205,11 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1pixels (J
 {
     GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
     guchar *result_g = gdk_pixbuf_get_pixels (pixbuf_g);
-    jsize result_len = result_g ? strlen ((gchar*)result_g) : 0;
+    jsize result_len = result_g ? 
+	    gdk_pixbuf_get_rowstride(pixbuf_g)*(gdk_pixbuf_get_height(pixbuf_g) - 1) +
+	    gdk_pixbuf_get_width(pixbuf_g)*gdk_pixbuf_get_n_channels(pixbuf_g) 
+	    : 0;
+    
     jbyteArray result_j = result_g ? (*env)->NewByteArray (env, result_len) : NULL;
     if (result_g) 
     	(*env)->SetByteArrayRegion (env, result_j, 0, result_len, (jbyte*)result_g);
@@ -665,7 +669,7 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1option (J
     gchar* key_g = (gchar*)g_malloc(key_len + 1);
     (*env)->GetByteArrayRegion(env, key, 0, key_len, (jbyte*)key_g);
     key_g[key_len] = 0;
-    gchar *result_g = (gchar*)gdk_pixbuf_get_option (pixbuf_g, key_g);
+    const gchar *result_g = (gchar*)gdk_pixbuf_get_option (pixbuf_g, key_g);
     jsize result_len = result_g ? strlen (result_g) : 0;
     jbyteArray result_j = result_g ? (*env)->NewByteArray (env, result_len) : NULL;
     if (result_g) 
