@@ -34,7 +34,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_PixbufLoader_gdk_1pixbuf_1loader_1get_1t
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_PixbufLoader_gdk_1pixbuf_1loader_1new (JNIEnv *env, 
     jclass cls) 
 {
-    return getGObjectHandle(env, G_OBJECT(gdk_pixbuf_loader_new ()));
+    return getGObjectHandleAndRef(env, G_OBJECT(gdk_pixbuf_loader_new ()));
 }
 
 /*
@@ -46,7 +46,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_PixbufLoader_gdk_1pixbuf_1loader_1new
 {
     const gchar* imageType_g = (*env)->GetStringUTFChars(env, imageType, 0);
     jobject result = 
-        getGObjectHandle(env, 
+        getGObjectHandleAndRef(env, 
                          G_OBJECT(gdk_pixbuf_loader_new_with_type (imageType_g, 
 								   (GError**)NULL)));
     (*env)->ReleaseStringUTFChars(env, imageType, imageType_g);
