@@ -9,10 +9,12 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_gtk_CellRendererProgress
 #define _Included_org_gnu_gtk_CellRendererProgress
+#include "org_gnu_gtk_CellRendererProgress.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -34,7 +36,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_CellRendererProgress_gtk_1cell_1renderer
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_CellRendererProgress_gtk_1cell_1renderer_1progress_1new
   (JNIEnv *env, jclass cls)
 {
-	return getHandleFromPointer(env, gtk_cell_renderer_progress_new());
+	return getGObjectHandle(env, (GObject *) gtk_cell_renderer_progress_new());
 }
 
 #ifdef __cplusplus
