@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_CellRendererText.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -25,7 +26,7 @@ Java_org_gnu_gtk_CellRendererText_gtk_1setAttributes (
 {
     GtkCellRendererText *renderer_g = (GtkCellRendererText *)getPointerFromHandle(env, renderer);
     PangoAttrList* attr_g = (PangoAttrList*)getPointerFromHandle(env, attr);
-	g_object_set(renderer_g, "attributes", attr_g);
+	g_object_set(renderer_g, "attributes", attr_g, NULL);
 }
 
 JNIEXPORT void JNICALL 
@@ -34,7 +35,7 @@ Java_org_gnu_gtk_CellRendererText_gtk_1setFont (
 {
     GtkCellRendererText *renderer_g = (GtkCellRendererText *)getPointerFromHandle(env, renderer);
     PangoFontDescription *font_g = (PangoFontDescription*)getPointerFromHandle(env, font);
-	g_object_set( renderer_g, "font-desc", font_g);
+	g_object_set( renderer_g, "font-desc", font_g, NULL);
 }
 
 JNIEXPORT jobject JNICALL 
@@ -43,7 +44,7 @@ Java_org_gnu_gtk_CellRendererText_gtk_1getFont (
 {
     GtkCellRendererText *renderer_g = (GtkCellRendererText *)getPointerFromHandle(env, renderer);
 	PangoFontDescription *desc = pango_font_description_new();
-	g_object_get( renderer_g, "font-desc", desc);
+	g_object_get( renderer_g, "font-desc", desc, NULL);
 	return getGBoxedHandle(env, desc, PANGO_TYPE_FONT_DESCRIPTION, NULL,
 			(JGFreeFunc) pango_font_description_free);
 }
