@@ -14,6 +14,7 @@
 
 #ifndef _Included_org_gnu_gtk_FileChooserHelper
 #define _Included_org_gnu_gtk_FileChooserHelper
+#include "org_gnu_gtk_FileChooserHelper.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -105,6 +106,11 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_
   (JNIEnv *env, jclass cls, jobject chooser)
 {
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
+	char* result = (char*) gtk_file_chooser_get_filename(chooser_g);
+	
+	if(result == NULL)
+		return NULL;
+	
 	return (*env)->NewStringUTF(env, (char*)gtk_file_chooser_get_filename(chooser_g));
 }
 
@@ -458,7 +464,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1cho
   (JNIEnv *env, jclass cls, jobject chooser)
 {
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
-	return getHandleArrayFromGSList(env, gtk_file_chooser_list_filters(chooser_g));
+	return getGObjectHandlesFromGSListAndRef(env, gtk_file_chooser_list_filters(chooser_g));
 }
 
 /*
@@ -488,42 +494,43 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_add_shortcut_folder
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1add_1shortcut_1folder
-  (JNIEnv *env, jclass cls, jobject chooser, jstring folder, jobject error)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1add_1shortcut_1folder
+  (JNIEnv *env, jclass cls, jobject chooser, jstring folder)
 {
 	const gchar* str;
 	GError* err;
-	gboolean bool;
+	gboolean gbool;
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
 	
 	str = (gchar*)(*env)->GetStringUTFChars(env, folder, NULL);
-	err = (GError*) getPointerFromHandle(env, error);
-	bool = gtk_file_chooser_add_shortcut_folder(chooser_g, str, &err);
-	updateHandle(env, error, err);
+	err = NULL;
+	gbool = gtk_file_chooser_add_shortcut_folder(chooser_g, str, &err);
 	(*env)->ReleaseStringUTFChars(env, folder, str);
-	(*env)->ReleaseIntArrayElements(env, error, (jint*)err, 0);
-	return (jboolean)bool;
+	if (gbool == TRUE)	{
+		return NULL;
+	}
+	return getStructHandle(env, err, NULL, (JGFreeFunc) g_error_free);
 }
 
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_remove_shortcut_folder
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1remove_1shortcut_1folder
-  (JNIEnv *env, jclass cls, jobject chooser, jstring folder, jintArray error)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1remove_1shortcut_1folder
+  (JNIEnv *env, jclass cls, jobject chooser, jstring folder)
 {
 	const gchar* str;
 	GError* err;
-	gboolean bool;
+	gboolean gbool;
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
 	
 	str = (gchar*)(*env)->GetStringUTFChars(env, folder, NULL);
-	err = (GError*) getPointerFromHandle(env, error);
-	bool = gtk_file_chooser_remove_shortcut_folder(chooser_g, str, &err);
-	updateHandle(env, error, err);
+	gbool = gtk_file_chooser_remove_shortcut_folder(chooser_g, str, &err);
 	(*env)->ReleaseStringUTFChars(env, folder, str);
-	(*env)->ReleaseIntArrayElements(env, error, (jint*)err, 0);
-	return (jboolean)bool;
+	if (gbool == TRUE)	{
+		return NULL;
+	}
+	return getStructHandle(env, err, NULL, (JGFreeFunc) g_error_free);
 }
 
 /*
@@ -562,42 +569,42 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1cho
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_add_shortcut_folder_uri
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1add_1shortcut_1folder_1uri
-  (JNIEnv *env, jclass cls, jobject chooser, jstring folder, jintArray error)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1add_1shortcut_1folder_1uri
+  (JNIEnv *env, jclass cls, jobject chooser, jstring folder)
 {
 	const gchar* str;
 	GError* err;
-	gboolean bool;
+	gboolean gbool;
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
 	
 	str = (gchar*)(*env)->GetStringUTFChars(env, folder, NULL);
-	err = (GError*) getPointerFromHandle(env, error);
-	bool = gtk_file_chooser_add_shortcut_folder_uri(chooser_g, str, &err);
-	updateHandle(env, error, err);
+	gbool = gtk_file_chooser_add_shortcut_folder_uri(chooser_g, str, &err);
 	(*env)->ReleaseStringUTFChars(env, folder, str);
-	(*env)->ReleaseIntArrayElements(env, error, (jint*)err, 0);
-	return (jboolean)bool;
+	if (gbool == TRUE)	{
+		return NULL;
+	}
+	return getStructHandle(env, err, NULL, (JGFreeFunc) g_error_free);
 }
 
 /*
  * Class:     org_gnu_gtk_FileChooserHelper
  * Method:    gtk_file_chooser_remove_shortcut_folder_uri
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1remove_1shortcut_1folder_1uri
-  (JNIEnv *env, jclass cls, jobject chooser, jstring folder, jintArray error)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserHelper_gtk_1file_1chooser_1remove_1shortcut_1folder_1uri
+  (JNIEnv *env, jclass cls, jobject chooser, jstring folder)
 {
 	const gchar* str;
 	GError* err;
-	gboolean bool;
+	gboolean gbool;
 	GtkFileChooser* chooser_g = (GtkFileChooser*)getPointerFromHandle(env, chooser);
 	
 	str = (gchar*)(*env)->GetStringUTFChars(env, folder, NULL);
-	err = (GError*) getPointerFromHandle(env, error);
-	bool = gtk_file_chooser_remove_shortcut_folder_uri(chooser_g, str, &err);
-	updateHandle(env, error, err);
+	gbool = gtk_file_chooser_remove_shortcut_folder_uri(chooser_g, str, &err);
 	(*env)->ReleaseStringUTFChars(env, folder, str);
-	(*env)->ReleaseIntArrayElements(env, error, (jint*)err, 0);
-	return (jboolean)bool;
+	if (gbool == TRUE)	{
+		return NULL;
+	}
+	return getStructHandle(env, err, NULL, (JGFreeFunc) g_error_free);
 }
 
 /*
