@@ -9,10 +9,12 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_gtk_FileChooserWidget
 #define _Included_org_gnu_gtk_FileChooserWidget
+#include "org_gnu_gtk_FileChooserWidget.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -34,7 +36,8 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_FileChooserWidget_gtk_1file_1chooser_1wi
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FileChooserWidget_gtk_1file_1chooser_1widget_1new
   (JNIEnv *env, jclass cls, jint action)
 {
-	return getHandleFromPointer(env, gtk_file_chooser_widget_new((GtkFileChooserAction)action));
+	return getGObjectHandle(env, (GObject *) gtk_file_chooser_widget_new(
+			(GtkFileChooserAction)action));
 }
 
 #ifdef __cplusplus
