@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_HRuler.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -31,7 +33,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_HRuler_gtk_1hruler_1get_1type (JNIEnv *e
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HRuler_gtk_1hruler_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_hruler_new ());
+    return getGObjectHandle(env, (GObject *) gtk_hruler_new ());
 }
 
 
