@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_HScale.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -33,7 +35,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HScale_gtk_1hscale_1new (JNIEnv *env,
     adjustment) 
 {
     GtkAdjustment *adjustment_g = (GtkAdjustment *)getPointerFromHandle(env, adjustment);
-    return getHandleFromPointer(env, gtk_hscale_new (adjustment_g));
+    return getGObjectHandle(env, (GObject *) gtk_hscale_new (adjustment_g));
 }
 
 /*
@@ -46,7 +48,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HScale_gtk_1hscale_1new_1with_1range
     gdouble min_g = (gdouble) min;
     gdouble max_g = (gdouble) max;
     gdouble step_g = (gdouble) step;
-    return getHandleFromPointer(env, gtk_hscale_new_with_range (min_g, max_g, step_g));
+    return getGObjectHandle(env, (GObject *) gtk_hscale_new_with_range (min_g, max_g, step_g));
 }
 
 #ifdef __cplusplus
