@@ -10,13 +10,21 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_TreePath.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
+static jobject getTreePath(JNIEnv* env, GtkTreePath* path)
+{
+	return getGBoxedHandle(env, path, GTK_TYPE_TREE_PATH,
+			NULL, (GBoxedFreeFunc) gtk_tree_path_free);	
+}
+
 /*
  * Class:     org.gnu.gtk.TreePath
  * Method:    gtk_tree_path_new
@@ -24,7 +32,7 @@ extern "C"
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_tree_path_new ());
+    return getTreePath(env, gtk_tree_path_new ());
 }
 
 /*
@@ -36,7 +44,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1new_1from_1
 {
     const gchar* path_g = (*env)->GetStringUTFChars( env, path, NULL );
     jobject retval = 
-        getHandleFromPointer(env, gtk_tree_path_new_from_string (path_g));
+        getTreePath(env, gtk_tree_path_new_from_string (path_g));
     (*env)->ReleaseStringUTFChars(env, path, path_g);
     return retval;
 }
@@ -46,7 +54,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1new_1from_1
  * Method:    gtk_tree_path_to_string
  * Signature: (I)[B
  */
-JNIEXPORT jstring JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1to_1string (JNIEnv *env, jclass cls, jobject path) 
+JNIEXPORT jstring JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1to_1string 
+(JNIEnv *env, jclass cls, jobject path) 
 {
     GtkTreePath *path_g = (GtkTreePath *)getPointerFromHandle(env, path);
     return (*env)->NewStringUTF( env, gtk_tree_path_to_string (path_g) );
@@ -59,7 +68,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1to_1string
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreePath_gtk_1tree_1path_1new_1first (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_tree_path_new_first ());
+    return getTreePath(env, gtk_tree_path_new_first ());
 }
 
 /*
