@@ -884,7 +884,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1screen(JNIEnv *
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Window_gtk_1window_1get_1screen(JNIEnv *env, jclass cls, jobject window)
 {
     GtkWindow *window_g = (GtkWindow *)getPointerFromHandle(env, window);
-    return getGObjectHandle(env, (GObject *) gtk_window_get_screen(window_g));
+    return getGObjectHandleAndRef(env, (GObject *) gtk_window_get_screen(window_g));
 }
 
 /*
