@@ -11,13 +11,14 @@
 #include <pango/pango.h>
 #include "jg_jnu.h"
 
+#include "org_gnu_pango_AttrString.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
 
-gchar * PangoAttrString_get_value (PangoAttrString * cptr) 
+static gchar * PangoAttrString_get_value (PangoAttrString * cptr) 
 {
     return cptr->value;
 }
